"""
    test_components
    ~~~~~~~~~~~~
    tests for components
"""

import unittest
# import json
# import requests
# from mock import patch

from domonic.html import *
from domonic.JSON import *


# class TestCase(unittest.TestCase):

#     def test_json(self):



# if __name__ == '__main__':
#     unittest.main()
